Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(859)

Unified Diff: ppapi/c/private/ppb_instance_private.h

Issue 6871040: Rename Instance_Trusted to Instance_Private, wire it up in Chrome. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix up based on review comments. Created 9 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | ppapi/c/private/ppp_instance_private.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ppapi/c/private/ppb_instance_private.h
diff --git a/ppapi/c/trusted/ppb_instance_trusted.h b/ppapi/c/private/ppb_instance_private.h
similarity index 85%
rename from ppapi/c/trusted/ppb_instance_trusted.h
rename to ppapi/c/private/ppb_instance_private.h
index 44c9f77965a1f560f18edb6537f6a02389894b15..730d909a88dc6a70952ce0be8c46e9bac1e56b04 100644
--- a/ppapi/c/trusted/ppb_instance_trusted.h
+++ b/ppapi/c/private/ppb_instance_private.h
@@ -2,17 +2,17 @@
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
-#ifndef PPAPI_C_TRUSTED_PPB_INSTANCE_TRUSTED_H_
-#define PPAPI_C_TRUSTED_PPB_INSTANCE_TRUSTED_H_
+#ifndef PPAPI_C_PRIVATE_PPB_INSTANCE_PRIVATE_H_
+#define PPAPI_C_PRIVATE_PPB_INSTANCE_PRIVATE_H_
#include "ppapi/c/pp_instance.h"
#include "ppapi/c/pp_var.h"
-#define PPB_INSTANCE_TRUSTED_INTERFACE "PPB_Instance_Trusted;0.1"
+#define PPB_INSTANCE_PRIVATE_INTERFACE "PPB_Instance_Private;0.1"
/**
* @file
* This file defines the PPB_Instance_Trusted interface implemented by the
* browser and containing pointers to functions available only to trusted plugin
* instances.
*
@@ -21,11 +21,11 @@
*/
/**
* The PPB_Instance_Trusted interface contains functions available only to
* trusted plugin instances.
*
*/
-struct PPB_Instance_Trusted {
+struct PPB_Instance_Private {
/**
* GetWindowObject is a pointer to a function that determines
* the DOM window containing this module instance.
@@ -70,5 +70,5 @@ struct PPB_Instance_Trusted {
* @}
*/
-#endif /* PPAPI_C_TRUSTED_PPB_INSTANCE_TRUSTED_H_ */
+#endif /* PPAPI_C_PRIVATE_PPB_INSTANCE_PRIVATE_H_ */
« no previous file with comments | « no previous file | ppapi/c/private/ppp_instance_private.h » ('j') | no next file with comments »

Powered by Google App Engine
@@ -2,17 +2,17 @@
/**
* @file
- * This file defines the PPB_Instance_Trusted interface implemented by the
+ * This file defines the PPB_Instance_Private interface implemented by the
* browser and containing pointers to functions available only to trusted plugin
* instances.
@@ -21,11 +21,11 @@
*/
/**
- * The PPB_Instance_Trusted interface contains functions available only to
+ * The PPB_Instance_Private interface contains functions available only to
* trusted plugin instances.
*
This is Rietveld 408576698